@@ -24,8 +24,6 @@ def serializer(schema=None, many=False):
     def factory(func):
         @wraps(func)
         def decorator(*args, **kwargs):
-            if not schema:
-                return func(*args, **kwargs)
 
             appended_kws = kwargs.pop('appended_kws', None)
 
@@ -49,7 +47,11 @@ def serializer(schema=None, many=False):
                 inputs = client_data  # .to_dict()
                 if appended_kws:
                     inputs.update(appended_kws)
-                result = schema(many=many).load(inputs)
+
+                if not schema:
+                    result = schema(many=many).load(inputs)
+                else:
+                    result = inputs
             except ValidationError as e:
                 raise AppValidationError(e.messages)
 
