@@ -2,7 +2,7 @@ import platform
 from datetime import datetime
 
 from .kafka_producer import Producer
-from ... import WeDeliverCore
+from .. import WeDeliverCore
 
 INTERNAL_NOTIFICATION_MESSAGE = "internal_notification_message"
 
